Method: Aws::DLM::Types::CreateLifecyclePolicyRequest#policy_details

Defined in:
lib/aws-sdk-dlm/types.rb

#policy_detailsTypes::PolicyDetails

The configuration details of the lifecycle policy.

If you create a default policy, you can specify the request parameters either in the request body, or in the PolicyDetails request structure, but not both.



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aws-sdk-dlm/types.rb', line 180

class CreateLifecyclePolicyRequest < Struct.new(
  :execution_role_arn,
  :description,
  :state,
  :policy_details,
  :tags,
  :default_policy,
  :create_interval,
  :retain_interval,
  :copy_tags,
  :extend_deletion,
  :cross_region_copy_targets,
  :exclusions)
  SENSITIVE = []
  include Aws::Structure
end