Class: Aws::DLM::Types::FastRestoreRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::DLM::Types::FastRestoreRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-dlm/types.rb
Overview
**[Custom snapshot policies only]** Specifies a rule for enabling fast snapshot restore for snapshots created by snapshot policies. You can enable fast snapshot restore based on either a count or a time interval.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_ids ⇒ Array<String>
The Availability Zone Ids in which to enable fast snapshot restore.
-
#availability_zones ⇒ Array<String>
The Availability Zones in which to enable fast snapshot restore.
-
#count ⇒ Integer
The number of snapshots to be enabled with fast snapshot restore.
-
#interval ⇒ Integer
The amount of time to enable fast snapshot restore.
-
#interval_unit ⇒ String
The unit of time for enabling fast snapshot restore.
Instance Attribute Details
#availability_zone_ids ⇒ Array<String>
The Availability Zone Ids in which to enable fast snapshot restore.
689 690 691 692 693 694 695 696 697 |
# File 'lib/aws-sdk-dlm/types.rb', line 689 class FastRestoreRule < Struct.new( :count, :interval, :interval_unit, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#availability_zones ⇒ Array<String>
The Availability Zones in which to enable fast snapshot restore.
689 690 691 692 693 694 695 696 697 |
# File 'lib/aws-sdk-dlm/types.rb', line 689 class FastRestoreRule < Struct.new( :count, :interval, :interval_unit, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Integer
The number of snapshots to be enabled with fast snapshot restore.
689 690 691 692 693 694 695 696 697 |
# File 'lib/aws-sdk-dlm/types.rb', line 689 class FastRestoreRule < Struct.new( :count, :interval, :interval_unit, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#interval ⇒ Integer
The amount of time to enable fast snapshot restore. The maximum is 100 years. This is equivalent to 1200 months, 5200 weeks, or 36500 days.
689 690 691 692 693 694 695 696 697 |
# File 'lib/aws-sdk-dlm/types.rb', line 689 class FastRestoreRule < Struct.new( :count, :interval, :interval_unit, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |
#interval_unit ⇒ String
The unit of time for enabling fast snapshot restore.
689 690 691 692 693 694 695 696 697 |
# File 'lib/aws-sdk-dlm/types.rb', line 689 class FastRestoreRule < Struct.new( :count, :interval, :interval_unit, :availability_zones, :availability_zone_ids) SENSITIVE = [] include Aws::Structure end |