Method: Aws::DLM::Types::UpdateLifecyclePolicyRequest#exclusions

Defined in:
lib/aws-sdk-dlm/types.rb

#exclusionsTypes::Exclusions

**[Default policies only]** Specifies exclusion parameters for volumes or instances for which you do not want to create snapshots or AMIs. The policy will not create snapshots or AMIs for target resources that match any of the specified exclusion parameters.



1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
# File 'lib/aws-sdk-dlm/types.rb', line 1776

class UpdateLifecyclePolicyRequest < Struct.new(
  :policy_id,
  :execution_role_arn,
  :state,
  :description,
  :policy_details,
  :create_interval,
  :retain_interval,
  :copy_tags,
  :extend_deletion,
  :cross_region_copy_targets,
  :exclusions)
  SENSITIVE = []
  include Aws::Structure
end