Method: Aws::DLM::Types::CreateLifecyclePolicyRequest#exclusions
- Defined in:
- lib/aws-sdk-dlm/types.rb
#exclusions ⇒ Types::Exclusions
**[Default policies only]** Specifies exclusion parameters for volumes or instances for which you do not want to create snapshots or AMIs. The policy will not create snapshots or AMIs for target resources that match any of the specified exclusion parameters.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/aws-sdk-dlm/types.rb', line 180 class CreateLifecyclePolicyRequest < Struct.new( :execution_role_arn, :description, :state, :policy_details, :tags, :default_policy, :create_interval, :retain_interval, :copy_tags, :extend_deletion, :cross_region_copy_targets, :exclusions) SENSITIVE = [] include Aws::Structure end |